==> GANN-Beta-0.5.tar.gz: GANN/src/ggendata.cpp <==
/* 
   
   Geeks Artificial Neural Network (G.A.N.N) - Generate Random Data
   
   Copyright GNU/GPL 2006 George Delaportas (qtgeo)
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA

*/



//Include Prototypes
#include "headers/ggendata.h"

//Geeks Generate Data (Function)
float GGenData(int FuncType,int Range)

{

    float RandomData;
    
    //Randomize
    GRand();
    
    //Check Function Type (0:Binary,1:Real)
    if (FuncType==0 && Range==0)
    
    {
    
        //Produce Random Binary Data
        RandomData=rand()%2;
    
    }
    
    else if (FuncType==1 && Range>0)
    
    {
    
        //Produce Random Real Data
        RandomData=rand()%Range;
    
    }
    
    else
    
    {

        printf("Error: Wrong Function Type Of Range Specified!\n");
        
        exit(1);
    
    }
    
    //Give Results
    return RandomData;

}

/* ------------------------------------------------------------------------ */

==> GANN-Beta-0.9.tar.gz: GANN/src/ggendata.cpp <==
/* 
   
   Geeks Artificial Neural Network (G.A.N.N) - Generate Random Data
   
   Copyright GNU/GPL 2006 George Delaportas (qtgeo)
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA

*/



//Geeks Generate Data (Function)
float GGenData(int FuncType,float Val)

{

    float RandomData;
    
    //Randomize
    GRand();
    
    //Check Function Type (0:Binary,1:Real)
    if (FuncType==0 && Val==0.0)
    
    {
    
        //Produce Random Binary Data
        RandomData=rand()%2;
    
    }
    
    else if (FuncType==1)
    
    {
    
        //Produce Random Real Data
        RandomData=rand()%int(Val+1);
    
    }
    
    else
    
    {

        printf("Error: Wrong Function Type Or Value Specified!\n");
        
        exit(1);
    
    }
    
    //Give Results
    return RandomData;

}



//Geeks Generate Data (Function) [Over-Loaded]
float GGenData(float Val1,float Val2)

{

    float RandomData;
    
    //Randomize
    GRand();
    
    //Check Range
    if (Val2>=Val1)
    
    {
    
        //Produce Random Real Data
        RandomData=Val1+rand()%int(Val2+1);
    
    }
    
    else
    
    {

        printf("Error: Wrong Function Type Or Range Specified!\n");
        
        exit(1);
    
    }
    
    //Give Results
    return RandomData;

}

/* ------------------------------------------------------------------------ */
